<?php


include_once( 'generic.class.php' );

class SignUp extends Generic {

	private $token;
	private $error;
	private $captchaError;
	private $settings = array();

	function __construct() {

	
	
		// Has the form been submitted?
		if(!empty($_POST)) {

			// Sign up form post data
			foreach ($_POST as $field => $value)
				$this->settings[$field] = parent::secure($value);

			$this->process();

		}

	

	}

	public function profileSignUpFields() {

		$sql = 'SELECT * FROM `login_profile_fields` WHERE `signup` <> "hide";';
		$stmt = parent::query($sql);

		while($row = $stmt->fetch(PDO::FETCH_ASSOC)) :
			$option = array(
				'name'  => $row['label'],
				'id'    => $row['id'],
				'type'  => $row['type'],
				'class' => $row['signup'] === 'require' ? 'required' : '',
			);
			parent::profileFieldTypes($option, true);
		endwhile;

	}

	public function doCaptcha($display = true) {

		$captcha = parent::getOption('integration-captcha');
		switch ( $captcha ) :

			case 'reCAPTCHA' :

				require_once('captcha/recaptcha-1.11/recaptchalib.php');
				$publickey  = parent::getOption('reCAPTCHA-public-key');
				$privatekey = parent::getOption('reCAPTCHA-private-key');

				/* Captcha has been submitted. */
				if ( ! empty($_POST['recaptcha_response_field'])) {

					$resp = recaptcha_check_answer( $privatekey, $_SERVER["REMOTE_ADDR"], $_POST["recaptcha_challenge_field"], $_POST["recaptcha_response_field"] );
					if ( !$resp->is_valid ) $this->captchaError = $resp->error;

				} else {

					$this->captchaError = true;

				}

				if ( $display )
					echo recaptcha_get_html($publickey, $this->captchaError);

				break;

			case 'playThru' :

				if ( !defined ('AYAH_PUBLISHER_KEY') )    define( 'AYAH_PUBLISHER_KEY'   , parent::getOption('playThru-publisher-key') );
				if ( !defined ('AYAH_SCORING_KEY') )      define( 'AYAH_SCORING_KEY'     , parent::getOption('playThru-scoring-key') );
				if ( !defined ('AYAH_WEB_SERVICE_HOST') ) define( 'AYAH_WEB_SERVICE_HOST', 'ws.areyouahuman.com' );

				require_once('captcha/ayah-1.0.2/ayah.php');

				$integration = new AYAH();

				if ( (!$display && !empty($_POST)) && !$integration->scoreResult() )
					$this->captchaError = true;

				/* Show the captcha form. */
				if ( $display )
					echo $integration->getPublisherHTML();

				break;

		endswitch;

	}

	private function process() {

		// Check that the token is valid, prevents exploits
	
		/* Check the captcha response. */
		$this->doCaptcha(false);

		// See if all the values are correct
		$this->validate();

		// Sign um up!
		$this->register();

	}

	private function validate() {

		
		// Checkbox handling
		$sql = "SELECT * FROM `login_profile_fields` WHERE `signup` <> 'hide';";
		$stmt = parent::query($sql);

		
		// Output the errors in a pretty format :]
		$this->error = (isset($this->error)) ? "<div class='alert alert-error alert-block'><h4 class='alert-heading'>"._('Attention!')."</h4>$this->error</div>" : '';

	}

	// Return a value if it exists
	public function getPost($var) {

		if ( !empty($_SESSION['leopedia']['openIDMisc']) ) :

			$misc = $_SESSION['leopedia']['openIDMisc'];

			switch ($var) :

				case 'email' :
					return $misc['contact/email'];
					break;

				case 'name' :
					return $misc['namePerson/first'] . ' ' . $misc['namePerson/last'];
					break;

			endswitch;

		endif;

		if ( !empty($_SESSION['leopedia']['facebookMisc']) ) :

			$misc = $_SESSION['leopedia']['facebookMisc'];

			switch ($var) :

				case 'email' :
					return $misc['email'];
					break;

				case 'name' :
					return $misc['name'];
					break;

			endswitch;

		endif;

		if ( !empty($_SESSION['leopedia']['twitterMisc']) ) :

			$misc = $_SESSION['leopedia']['twitterMisc'];

			switch ($var) :

				case 'username' :
					return $misc['username'];
					break;

				case 'name' :
					return $misc['name'];
					break;

			endswitch;

		endif;

		return empty($this->settings[$var]) ? '' : $this->settings[$var];

	}

	// Once everything's filled out
	private function register() {

		if(empty($this->error)) {

			/* See if the admin requires new users to activate */
			$requireActivate = parent::getOption('user-activation-enable');

			/* Log user in when they register */
			$_SESSION['leopedia']['username'] = $this->settings['username'];

			/* Apply default user_level */
			$_SESSION['leopedia']['user_level'] = unserialize(parent::getOption('default-level'));

			if ( $requireActivate )
				$_SESSION['leopedia']['activate'] = 1;

			$_SESSION['leopedia']['gravatar'] = parent::get_gravatar($this->settings['email'], true, 26);
$today=date('Y-m-d');
			/* Create their account */
			$sql = ("INSERT INTO contect ( `projectname`,`name`, `email`, `mobileno`, `message`, `register_on`) VALUES ('".$_POST['projectname']."','".$_POST['name']."', '".$_POST['email']."','".$_POST['mobileno']."','".$_POST['message']."', '".$today."');");
			$params = array(
				':user_level' => parent::getOption('default-level'),
				':name'       => $this->settings['name'],
				':email'      => $this->settings['email'],
				':username'   => $this->settings['username'],
				':password'   => parent::hashPassword($this->settings['password'])
			);
			parent::query($sql, $params);

			$user_id = parent::$dbh->lastInsertId();
			$_SESSION['leopedia']['user_id'] = $user_id;

			/* Social integration. */
			if ( !empty($_SESSION['leopedia']['facebookMisc']) ) {
				$link = 'facebook';
				$id = $_SESSION['leopedia']['facebookMisc']['id'];
			}

			if ( !empty($_SESSION['leopedia']['openIDMisc']) ) {
				$link = $_SESSION['leopedia']['openIDMisc']['type'];
				$id = $_SESSION['leopedia']['openIDMisc'][$link];
			}

			if ( !empty($_SESSION['leopedia']['twitterMisc']) ) {
				$link = 'twitter';
				$id = $_SESSION['leopedia']['twitterMisc']['id'];
			}

			if ( !empty($link) ) {

				$params = array(
					':user_id' => $user_id,
					':id'      => $id,
				);
				parent::query("INSERT INTO `login_integration` (`user_id`, `$link`) VALUES (:user_id, :id);", $params);

			}

			// Update profile fields
			foreach($this->settings as $field => $value) :
				if(strstr($field,'p-')) {
					$field = str_replace('p-', '', $field);
					parent::updateOption($field, $value, true, $user_id);
				}
			endforeach;

			/* Create the activation key */
			if ( $requireActivate ) :
				$key = md5(uniqid(mt_rand(),true));
				$sql = sprintf("INSERT INTO `login_confirm` (`username`, `key`, `email`, `type`)
								VALUES ('%s', '%s', '%s', '%s');",
								$this->settings['username'], $key, $this->settings['email'], 'new_user');
				parent::query($sql);
			endif;

			/* Send welcome email to new user. */
			$msg  =  "<table>
			<tr><td>Projectname:'".$_POST['projectname']."'</td></tr>
			<tr><td>Name:'".$_POST['name']."'</td></tr>
			<tr><td>Email:'".$_POST['email']."'</td></tr>
			<tr><td>Mobile No:'".$_POST['mobileno']."'</td></tr>
			<tr><td>Message:'".$_POST['message']."'</td></tr>
		</table>";
		
		
			
			
$today=date('Y-m-d');
			$shortcodes = array(
				'site_address' => SITE_PATH,
				'name'    => $_POST['name'],
				'email'     => $this->settings['username'],
				'mobileno'        => $this->settings['mobileno'],
				'message'        => $this->settings['message'],
				'register_on'        => $today
				
			);
			$sql = "SELECT * FROM `adminemail`";
$stmt = parent::query($sql, $params);
$row = $stmt->fetch(PDO::FETCH_ASSOC);

	
							
			$subj = $row['subject'];
if($row['mailsendto']=='1')
{
  $sqluser = "SELECT * FROM product a join login_users b on b.username=a.pname where a.name='".$_POST['projectname']."'";
$stmt = parent::query($sql, $params);
$row = $stmt->fetch(PDO::FETCH_ASSOC);	
	if($row['email']!='')
	{
	$a=$row['email'];
	} else
	{
		$a=$row['adminmailid'];
	}
}
if($row['mailsendto']=='0')
{
	$a=$row['adminmailid'];
}


			if(!parent::sendEmail($a, $subj, $msg, $shortcodes))

				$this->error = _('ERROR. Mail not sent');

			/* Admin notification of new user. */
			$notifyNewUsers = parent::getOption('notify-new-user-enable');
			if ( !empty($notifyNewUsers) ) :

				$msg  = parent::getOption('email-new-user-msg');
				$subj = parent::getOption('email-new-user-subj');
				unset($shortcodes['activate']);

				$userGroup = parent::getOption('notify-new-users');
				if ( !empty($userGroup) ) :
					$userGroup = unserialize($userGroup);

					/* Variable to store all the email addresses of each chosen group. */
					$emails = array();

					foreach ( $userGroup as $level_id ) :

						/* Grab all users within the user group. */
						$params = array( ':level_id' => '%:"' . $level_id . '";%' );
						$sql = "SELECT * FROM `login_users` WHERE `user_level` LIKE :level_id";
						$stmt = parent::query($sql, $params);

						/* Send email to each user in group. */
						while($row = $stmt->fetch(PDO::FETCH_ASSOC)) :
							$emails[] = $row['email'];
						endwhile;

					endforeach;

					/* Remove duplicates for users with multiple user groups. */
					$emails = array_unique($emails);

					if(!parent::sendEmail($emails, $subj, $msg, $shortcodes, true))
						$this->error = _('ERROR. Mail not sent');

				endif;

			endif;

			unset(
				$_SESSION['leopedia']['referer'],
				$_SESSION['leopedia']['token'],
				$_SESSION['leopedia']['facebookMisc'],
				$_SESSION['leopedia']['twitterMisc'],
				$_SESSION['leopedia']['openIDMisc']
			);

			/* After registering, redirect to the page the admin has set in Settings > General > Redirect Options. */
			 $currentFile = $_SERVER["PHP_SELF"];
    $parts = Explode('/', $currentFile);
     $page= $parts[count($parts) - 1] ;
	  $page1= $parts[count($parts) - 2] ;
 $siteurldatas="http://".$_SERVER["SERVER_NAME"]."/".$page1."/";
			?>
			<script type="text/javascript">

   window.location="<?php echo $siteurldatas; ?>detail/<?php echo $_GET['id']; ?>.html";

</script>
			<?php //header('Location: ' . parent::getOption('new-user-redirect') );
			exit();

		}

	}

}

$signUp = new SignUp();